Fields
key: i64Index into string table
str: i64At most one of the following must be present
Index into string table
num: i64num_unit: i64Should only be present when num is present. Specifies the units of num. Use arbitrary string (for example, “requests”) as a custom count unit. If no unit is specified, consumer may apply heuristic to deduce the unit. Consumers may also interpret units like “bytes” and “kilobytes” as memory units and units like “seconds” and “nanoseconds” as time units, and apply appropriate unit conversions to these.
Index into string table