pub struct Location {
pub id: u64,
pub mapping_id: u64,
pub address: u64,
pub line: Vec<Line>,
pub is_folded: bool,
}Expand description
Describes function and line table debug information.
Fields
id: u64Unique nonzero id for the location. A profile could use instruction addresses or any integer sequence as ids.
mapping_id: u64The id of the corresponding profile.Mapping for this location. It can be unset if the mapping is unknown or not applicable for this profile type.
address: u64The instruction address for this location, if available. It should be within [Mapping.memory_start…Mapping.memory_limit] for the corresponding mapping. A non-leaf address may be in the middle of a call instruction. It is up to display tools to find the beginning of the instruction if necessary.
line: Vec<Line>Multiple line indicates this location has inlined functions, where the last entry represents the caller into which the preceding entries were inlined.
E.g., if memcpy() is inlined into printf: line[0].function_name == “memcpy” line[1].function_name == “printf”
is_folded: boolProvides an indication that multiple symbols map to this location’s address, for example due to identical code folding by the linker. In that case the line information above represents one of the multiple symbols. This field must be recomputed when the symbolization state of the profile changes.